@@ -9,7 +9,7 @@
 */
 
 /* ====================================================================
- * Copyright (c) 1998-2004 Ralf S. Engelschall. All rights reserved.
+ * Copyright (c) 1998-2005 Ralf S. Engelschall. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -868,8 +868,8 @@ int ssl_hook_Access(request_rec *r)
                     && (nVerify    != SSL_VERIFY_NONE))
                 || (  !(nVerifyOld &  SSL_VERIFY_PEER)
                     && (nVerify    &  SSL_VERIFY_PEER))
-                || (  !(nVerifyOld &  (SSL_VERIFY_PEER|SSL_VERIFY_FAIL_IF_NO_PEER_CERT))
-                    && (nVerify    &  (SSL_VERIFY_PEER|SSL_VERIFY_FAIL_IF_NO_PEER_CERT)))) {
+                || (  !(nVerifyOld &  SSL_VERIFY_FAIL_IF_NO_PEER_CERT)
+                    && (nVerify    &  SSL_VERIFY_FAIL_IF_NO_PEER_CERT))) {
                 renegotiate = TRUE;
                 /* optimization */
                 if (   dc->nOptions & SSL_OPT_OPTRENEGOTIATE
